@@ -28,6 +28,8 @@
 #' (difference in log-likelihood)
 #' @param scale Scale multiplier for the covariance matrix of the t
 #' approximation
+#' @param quad.ask Logical, for method='quadrature'. Whether or not the sampler should ask if quadrature sampling should take place.
+#' It is used to stop the sampling if the number of likelihood evaluations would be extreme.
 #' @param force.quad A logical indicating whether or not to force the execution 
 #' of the quadrature method for large parameter vectors.
 #' @return
@@ -89,7 +91,7 @@
 #' @seealso See \code{demo(northernFurSealDemo)} for example.
 #' @export
 #' @import mvtnorm
-crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1, crit=2.5, scale=1, force.quad)
+crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1, crit=2.5, scale=1, quad.ask = T, force.quad)
 {
   if(!inherits(object.sim, 'crwSimulator'))
     stop("Argument needs to be of class 'crwSimulator'\nUse 'crwSimulator( )' to create")
@@ -106,8 +108,6 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
   y <- object.sim$y
   noObs <- object.sim$noObs
   delta <- object.sim$delta
-  a <- object.sim$a
-  P <- object.sim$P
   n.errX <- object.sim$n.errX
   n.errY <- object.sim$n.errY
   rho = object.sim$rho
@@ -117,7 +117,7 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
   upper <- object.sim$upper 
   prior <- object.sim$prior
   if(missing(force.quad)) force.quad=FALSE
-  message("\nComputing importance weights ...\n")
+  message("Computing importance weights ...")
   if(method=="IS"){
     thetaMat <- matrix(NA, size, length(fixPar)+3)
     for(i in 1:(size-1)){
@@ -128,8 +128,8 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
       if(df==Inf) dens <- dmvnorm(eps, sigma=scale*Cmat, log=TRUE) - dmvnorm(0.0*eps, sigma=scale*Cmat, log=TRUE)
       else dens <- dmvt(eps, sigma=scale*Cmat, df=df, log=TRUE) - dmvt(0.0*eps, sigma=scale*Cmat, df=df, log=TRUE)
       ln.prior = ifelse(!is.null(prior), prior(par[eInd]), 0)
-      n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta, a,
-                          P, mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
+      n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta,
+                          mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
                           n.errX, n.errY, n.mov, driftMod, prior, need.hess=FALSE, 
                           constr=list(lower=lower, upper=upper)) + ln.prior
       thetaMat[i,] <- c(-n2ll.val/2 - dens, -n2ll.val/2, dens, par)
@@ -161,8 +161,8 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
         par[eInd] <- parMLE[eInd] + V%*%D%*%z
         if(any(par[eInd]>upper) | any(par[eInd]<lower)) stop.grid <- FALSE
         else{
-          n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta, a,
-                              P, mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
+          n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta,
+                              mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
                               n.errX, n.errY, n.mov, driftMod, prior, need.hess=FALSE, 
                               constr=list(lower=lower, upper=upper))
           if(-(n2ll.mode - n2ll.val)/2 > crit) stop.grid <- FALSE
@@ -180,8 +180,8 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
         par[eInd] <- parMLE[eInd] + V%*%D%*%z
         if(any(par[eInd]>upper) | any(par[eInd]<lower)) stop.grid <- FALSE
         else{
-          n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta, a,
-                              P, mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
+          n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta,
+                              mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
                               n.errX, n.errY, n.mov, driftMod, prior, need.hess=FALSE, 
                               constr=list(lower=lower, upper=upper))
           if(-(n2ll.mode - n2ll.val)/2 > crit) stop.grid <- FALSE
@@ -195,7 +195,14 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
     grid.pts <- as.matrix(expand.grid(grid.list))
     grid.pts <- grid.pts[apply(grid.pts==0, 1, sum) < np-1, ]
     numEvals <- nrow(grid.pts)+nrow(thetaMat)
-    message("\nEvaluating ", nrow(grid.pts)+nrow(thetaMat), " quadrature points ...\n")
+    message("Evaluating ", nrow(grid.pts)+nrow(thetaMat), " quadrature points ...")
+    if(quad.ask){
+      ans = toupper(readline(prompt="Proceed? [y/n]: "))
+      if(ans!="Y"){
+        message("Parameter sampling stopped")
+        return(NULL)
+      }
+    }
     parFix <- ifelse(!eInd, parMLE, 0)
     for(i in 1:nrow(grid.pts)){
       z <- grid.pts[i,]
@@ -203,8 +210,8 @@ crwSamplePar <- function(object.sim, method="IS", size=1000, df=Inf, grid.eps=1,
       par[eInd] <- parMLE[eInd] + V%*%D%*%z
       if(any(par[eInd]>upper) | any(par[eInd]<lower)) next
       else{
-        n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta, a,
-                            P, mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
+        n2ll.val <- crwN2ll(par[eInd], fixPar, y, noObs, delta,
+                            mov.mf, err.mfX, err.mfY, rho=rho, activity=activity,
                             n.errX, n.errY, n.mov, driftMod, prior, need.hess=FALSE, 
                             constr=list(lower=lower, upper=upper))
         if(-(n2ll.mode - n2ll.val)/2 > crit) next
